@@ -64,7 +64,7 @@ struct _GstFFMpegVidDec
   gint pic_interlaced;
   /* GST_VIDEO_BUFFER_FLAG_RFF | GST_VIDEO_BUFFER_FLAG_TFF */
   gint pic_field_order;
-  gboolean pic_field_order_changed;
+  gboolean pic_interlaced_mixed;
   GstVideoMultiviewMode cur_multiview_mode;
   GstVideoMultiviewFlags cur_multiview_flags;
   /* current context */
@@ -93,6 +93,8 @@ struct _GstFFMpegVidDec
   gint pool_height;
   enum AVPixelFormat pool_format;
   GstVideoInfo pool_info;
+
+  gboolean needs_renegotation;
 };
 
 typedef struct _GstFFMpegVidDecClass GstFFMpegVidDecClass;
